"""
Init file for software factory
"""
from .vasp_factory import Vasp
